==> webgui_7.9.18.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Spanish/Asset_Map.pm <==
package WebGUI::i18n::Spanish::Asset_Map;
use utf8;
our $I18N = {
  'add point label' => {
    'lastUpdated' => '1253291321',
    'message' => 'Agregar Punto'
  },
  'assetName' => {
    'lastUpdated' => '1253291328',
    'message' => 'Mapa'
  },
  'error add unauthorized' => {
    'lastUpdated' => '1253291587',
    'message' => 'No está autorizado a agregar Puntos.'
  },
  'error delete unauthorized' => {
    'lastUpdated' => '1253291602',
    'message' => 'No está autorizado a eliminar Puntos'
  },
  'error edit unauthorized' => {
    'lastUpdated' => '1253291648',
    'message' => 'No está autorizado a editar este Punto'
  },
  'error set center unauthorized' => {
    'lastUpdated' => '1253291684',
    'message' => 'No está autorizado a establecer el area de presentación'
  },
  'groupIdAddPoint description' => {
    'lastUpdated' => '1253291712',
    'message' => 'Grupo que puede agregar Puntos al Mapa'
  },
  'groupIdAddPoint label' => {
    'lastUpdated' => '1253291726',
    'message' => '¿Quienes pueden agregar Puntos?'
  },
  'mapApiKey description' => {
    'lastUpdated' => '1253291767',
    'message' => 'La llave generada para este sitio por el API de Google Maps.'
  },
  'mapApiKey label' => {
    'lastUpdated' => '1253291777',
    'message' => 'Google Maps API Key'
  },
  'mapApiKey link' => {
    'lastUpdated' => '1253291795',
    'message' => 'Obtenga su Google Maps API Key'
  },
  'mapHeight description' => {
    'lastUpdated' => '1253291836',
    'message' => 'Altura del Mapa generado. Recuerde incluir las unidades (<strong>px</strong> para pixels o <strong>%</strong> para porcentaje).'
  },
  'mapHeight label' => {
    'lastUpdated' => '1253291881',
    'message' => 'Altura del Mapa'
  },
  'mapWidth description' => {
    'lastUpdated' => '1253291980',
    'message' => 'Anchura del Mapa generado. Recuerde incluir las unidades (<strong>px</strong> para pixels o <strong>%</strong> para porcentaje).'
  },
  'mapWidth label' => {
    'lastUpdated' => '1253291987',
    'message' => 'Anchura del Mapa'
  },
  'message delete success' => {
    'lastUpdated' => '1253292006',
    'message' => 'Punto eliminado'
  },
  'message set center success' => {
    'lastUpdated' => '1253292025',
    'message' => 'Area de exploración establecida con éxito.'
  },
  'message set point location' => {
    'lastUpdated' => '1253292046',
    'message' => 'Ubicación del Punto ha sido guardada'
  },
  'select a point' => {
    'lastUpdated' => '1257424828',
    'message' => 'Seleccione un Punto'
  },
  'set default viewing area label' => {
    'lastUpdated' => '1253292057',
    'message' => 'Establecer Area de Exploración'
  },
  'startLatitude description' => {
    'lastUpdated' => '1253292075',
    'message' => 'Latitud del Punto inicial del Mapa'
  },
  'startLatitude label' => {
    'lastUpdated' => '1253292086',
    'message' => 'Latitud Inicial'
  },
  'startLongitude description' => {
    'lastUpdated' => '1253292113',
    'message' => 'Longitud del Punto inicial del Mapa'
  },
  'startLongitude label' => {
    'lastUpdated' => '1253292122',
    'message' => 'Longitud Inicial'
  },
  'startZoom description' => {
    'lastUpdated' => '1253292138',
    'message' => 'Nivel de acercamiento del Punto inicial del Mapa'
  },
  'startZoom label' => {
    'lastUpdated' => '1253292152',
    'message' => 'Nivel Inicial de Acercamiento'
  },
  'templateIdEditPoint description' => {
    'lastUpdated' => '1253292170',
    'message' => 'Plantilla para editar un Punto del Mapa. Aparece dentro del Mapa.'
  },
  'templateIdEditPoint label' => {
    'lastUpdated' => '1253292179',
    'message' => 'Plantilla para Editar Punto'
  },
  'templateIdView description' => {
    'lastUpdated' => '1253292192',
    'message' => 'Plantilla para desplegar el Mapa.'
  },
  'templateIdView label' => {
    'lastUpdated' => '1253292203',
    'message' => 'Plantilla para Ver Mapa'
  },
  'templateIdViewPoint description' => {
    'lastUpdated' => '1253292220',
    'message' => 'Plantilla para ver un Punto en el Mapa. Aparecerá dentro del Mapa.'
  },
  'templateIdViewPoint label' => {
    'lastUpdated' => '1253292267',
    'message' => 'Plantilla para Ver Punto'
  },
  'workflowIdPoint description' => {
    'lastUpdated' => '1253292529',
    'message' => 'El Flujo de Trabajo a ejecutar cuando se agrega o edita un Punto en el Mapa.'
  },
  'workflowIdPoint label' => {
    'lastUpdated' => '1253292547',
    'message' => 'Flujo de Trabajo para Puntos'
  }
}
;

1;

==> webgui_7.10.28.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Spanish/Asset_Map.pm <==
package WebGUI::i18n::Spanish::Asset_Map;
use utf8;
our $I18N = {
  'add point label' => {
    'lastUpdated' => '1253291321',
    'message' => 'Agregar Punto'
  },
  'assetName' => {
    'lastUpdated' => '1253291328',
    'message' => 'Mapa'
  },
  'button_addPoint' => {
    'lastUpdated' => '1307450816',
    'message' => 'La plantilla de un botón con etiqueta localizada para Agregar un Punto.'
  },
  'button_setCenter' => {
    'lastUpdated' => '1307450838',
    'message' => 'La plantilla localizada de un botón para restablecer el Centro del Mapa.'
  },
  'canAddPoint' => {
    'lastUpdated' => '1307450852',
    'message' => 'Un condicional que indica si el usuario puede agregar puntos al Mapa.'
  },
  'canEdit' => {
    'lastUpdated' => '1307450869',
    'message' => 'Un condicional que indica si el usuario puede editar este Mapa.'
  },
  'error add unauthorized' => {
    'lastUpdated' => '1253291587',
    'message' => 'No está autorizado a agregar Puntos.'
  },
  'error delete unauthorized' => {
    'lastUpdated' => '1253291602',
    'message' => 'No está autorizado a eliminar Puntos'
  },
  'error edit unauthorized' => {
    'lastUpdated' => '1253291648',
    'message' => 'No está autorizado a editar este Punto'
  },
  'error set center unauthorized' => {
    'lastUpdated' => '1253291684',
    'message' => 'No está autorizado a establecer el area de presentación'
  },
  'groupIdAddPoint' => {
    'lastUpdated' => '1307450882',
    'message' => 'El GUID del Grupo que puede agregar Puntos al Mapa.'
  },
  'groupIdAddPoint description' => {
    'lastUpdated' => '1253291712',
    'message' => 'Grupo que puede agregar Puntos al Mapa'
  },
  'groupIdAddPoint label' => {
    'lastUpdated' => '1253291726',
    'message' => '¿Quienes pueden agregar Puntos?'
  },
  'map asset template variables' => {
    'lastUpdated' => '1307450890',
    'message' => 'Variables de Plantilla para Mapas'
  },
  'mapApiKey' => {
    'lastUpdated' => '1307450905',
    'message' => 'La clave para el API Google Maps'
  },
  'mapApiKey description' => {
    'lastUpdated' => '1253291767',
    'message' => 'La llave generada para este sitio por el API de Google Maps.'
  },
  'mapApiKey label' => {
    'lastUpdated' => '1253291777',
    'message' => 'Google Maps API Key'
  },
  'mapApiKey link' => {
    'lastUpdated' => '1253291795',
    'message' => 'Obtenga su Google Maps API Key'
  },
  'mapHeight' => {
    'lastUpdated' => '1307450915',
    'message' => 'La altura del Mapa en pixels.'
  },
  'mapHeight description' => {
    'lastUpdated' => '1253291836',
    'message' => 'Altura del Mapa generado. Recuerde incluir las unidades (<strong>px</strong> para pixels o <strong>%</strong> para porcentaje).'
  },
  'mapHeight label' => {
    'lastUpdated' => '1253291881',
    'message' => 'Altura del Mapa'
  },
  'mapPoints' => {
    'lastUpdated' => '1307450942',
    'message' => 'Un bucle que contiene todos los Puntos en el Mapa. Consulte las variables de plantilla para Puntos en el Mapa para una lista de las que están disponibles.'
  },
  'mapWidth' => {
    'lastUpdated' => '1307450951',
    'message' => 'Anchura del Mapa en pixels.'
  },
  'mapWidth description' => {
    'lastUpdated' => '1253291980',
    'message' => 'Anchura del Mapa generado. Recuerde incluir las unidades (<strong>px</strong> para pixels o <strong>%</strong> para porcentaje).'
  },
  'mapWidth label' => {
    'lastUpdated' => '1253291987',
    'message' => 'Anchura del Mapa'
  },
  'message delete success' => {
    'lastUpdated' => '1253292006',
    'message' => 'Punto eliminado'
  },
  'message set center success' => {
    'lastUpdated' => '1253292025',
    'message' => 'Area de exploración establecida con éxito.'
  },
  'message set point location' => {
    'lastUpdated' => '1253292046',
    'message' => 'Ubicación del Punto ha sido guardada'
  },
  'select a point' => {
    'lastUpdated' => '1257424828',
    'message' => 'Seleccione un Punto'
  },
  'selectPoint' => {
    'lastUpdated' => '1307450982',
    'message' => 'Una plantilla para un dropdown para centrar el Mapa en un Punto y mostrar su información.'
  },
  'set default viewing area label' => {
    'lastUpdated' => '1253292057',
    'message' => 'Establecer Area de Exploración'
  },
  'startLatitude' => {
    'lastUpdated' => '1307450999',
    'message' => 'La Latitud inicial para el centro del Mapa.'
  },
  'startLatitude description' => {
    'lastUpdated' => '1253292075',
    'message' => 'Latitud del Punto inicial del Mapa'
  },
  'startLatitude label' => {
    'lastUpdated' => '1253292086',
    'message' => 'Latitud Inicial'
  },
  'startLongitude' => {
    'lastUpdated' => '1307451010',
    'message' => 'La longitud inicial para el centro del Mapa.'
  },
  'startLongitude description' => {
    'lastUpdated' => '1253292113',
    'message' => 'Longitud del Punto inicial del Mapa'
  },
  'startLongitude label' => {
    'lastUpdated' => '1253292122',
    'message' => 'Longitud Inicial'
  },
  'startZoom' => {
    'lastUpdated' => '1307451026',
    'message' => 'El nivel de acercamiento inicial para el Mapa.'
  },
  'startZoom description' => {
    'lastUpdated' => '1253292138',
    'message' => 'Nivel de acercamiento del Punto inicial del Mapa'
  },
  'startZoom label' => {
    'lastUpdated' => '1253292152',
    'message' => 'Nivel Inicial de Acercamiento'
  },
  'templateIdEditPoint' => {
    'lastUpdated' => '1307451053',
    'message' => 'El GUID de la plantilla para agregar o editar un Punto.'
  },
  'templateIdEditPoint description' => {
    'lastUpdated' => '1253292170',
    'message' => 'Plantilla para editar un Punto del Mapa. Aparece dentro del Mapa.'
  },
  'templateIdEditPoint label' => {
    'lastUpdated' => '1253292179',
    'message' => 'Plantilla para Editar Punto'
  },
  'templateIdView' => {
    'lastUpdated' => '1307451069',
    'message' => 'El GUID de la Plantilla para presentar el Mapa.'
  },
  'templateIdView description' => {
    'lastUpdated' => '1253292192',
    'message' => 'Plantilla para desplegar el Mapa.'
  },
  'templateIdView label' => {
    'lastUpdated' => '1253292203',
    'message' => 'Plantilla para Ver Mapa'
  },
  'templateIdViewPoint' => {
    'lastUpdated' => '1307451082',
    'message' => 'El GUID de la Plantilla para presentar un Pnuto en el Mapa.'
  },
  'templateIdViewPoint description' => {
    'lastUpdated' => '1253292220',
    'message' => 'Plantilla para ver un Punto en el Mapa. Aparecerá dentro del Mapa.'
  },
  'templateIdViewPoint label' => {
    'lastUpdated' => '1253292267',
    'message' => 'Plantilla para Ver Punto'
  },
  'view template' => {
    'lastUpdated' => '1307451094',
    'message' => 'Plantilla para Mostrar Mapa'
  },
  'workflowIdPoint' => {
    'lastUpdated' => '1307451113',
    'message' => 'El GUID del Flujo de Trabajo para registrar un Punto en el Mapa.'
  },
  'workflowIdPoint description' => {
    'lastUpdated' => '1253292529',
    'message' => 'El Flujo de Trabajo a ejecutar cuando se agrega o edita un Punto en el Mapa.'
  },
  'workflowIdPoint label' => {
    'lastUpdated' => '1253292547',
    'message' => 'Flujo de Trabajo para Puntos'
  }
}
;

1;
